@@ -30,7 +30,7 @@ for maybe in allowed:
 		try:
 			cmd = subprocess.Popen(cmdline, stdout=subprocess.PIPE)
 		except Exception, exc:
-			print "Could not execute plugin: %s" % exc
+			print 'Could not execute plugin ("%s"): %s' % (' '.join(cmdline), exc)
 			sys.exit(3)
 		else:
 			print cmd.communicate()[0].rstrip()
